@@ -58,7 +58,7 @@ class Player(Gtk.Box):
         self.recommend_imgs = None
         self.curr_song = None
 
-        # use this to keep Net.AsyncSong and Net.AsyncMV object
+        # use this to keep Net.AsyncSong object
         self.async_song = None
         self.async_next_song = None
 
@@ -232,7 +232,7 @@ class Player(Gtk.Box):
         self.async_song.get_song(song)
 
     def failed_to_download(self, song_path, status):
-        self.pause_player()
+        self.stop_player_cb()
         
         if status == 'FileNotFoundError':
             Widgets.filesystem_error(self.app.window, song_path)
@@ -270,13 +270,10 @@ class Player(Gtk.Box):
                 self.playbin.load_video(uri, self.app.lrc.xid)
             self.start_player(load=True)
             self.update_player_info()
-        def _load_next():
-            self.load_next()
 
         if status == 'OK':
             GLib.idle_add(_on_song_can_play)
-        elif status == 'URLError':
-            print('current song has no link download, will get net song')
+        else:
             GLib.idle_add(self.failed_to_download, song_path, status)
 
     def on_song_downloaded(self, widget, song_path):
@@ -284,10 +281,9 @@ class Player(Gtk.Box):
             self.init_adjustment()
             if self.play_type in (PlayType.SONG, PlayType.MV):
                 self.app.playlist.on_song_downloaded(play=True)
-                _repeat = self.repeat_btn.get_active()
-                _shuffle = self.shuffle_btn.get_active()
                 self.next_song = self.app.playlist.get_next_song(
-                        shuffle=_shuffle, repeat=_repeat)
+                        self.repeat_btn.get_active(),
+                        self.shuffle_btn.get_active())
             elif self.play_type == PlayType.RADIO:
                 self.next_song = self.curr_radio_item.get_next_song()
             if self.next_song:
@@ -297,17 +293,13 @@ class Player(Gtk.Box):
             self.dbus.enable_seek()
 
         self.scale.set_sensitive(True)
-        if song_path:
-            GLib.idle_add(_on_song_download)
-        else:
-            #GLib.idle_add(self.failed_to_download, song_path)
-            pass
+        GLib.idle_add(_on_song_download)
 
     def cache_next_song(self):
         if self.play_type == PlayType.MV:
             # NOTE:if next song has no MV, cache will be failed
-            self.async_next_song= Net.AsyncMV(self.app)
-            self.async_next_song.get_mv(self.next_song)
+            self.async_next_song= Net.AsyncSong(self.app)
+            self.async_next_song.get_song(self.next_song, use_mv=True)
         elif self.play_type in (PlayType.SONG, PlayType.RADIO):
             self.async_next_song = Net.AsyncSong(self.app)
             self.async_next_song.get_song(self.next_song)
@@ -484,11 +476,11 @@ class Player(Gtk.Box):
         self.stop_player()
         self.scale.set_fill_level(0)
         self.scale.set_show_fill_level(True)
-        self.async_song = Net.AsyncMV(self.app)
+        self.async_song = Net.AsyncSong(self.app)
         self.async_song.connect('chunk-received', self.on_chunk_received)
         self.async_song.connect('can-play', self.on_song_can_play)
         self.async_song.connect('downloaded', self.on_song_downloaded)
-        self.async_song.get_mv(song)
+        self.async_song.get_song(song, use_mv=True)
 
     def get_mv_link(self):
         def _update_mv_link(mv_args, error=None):
@@ -589,11 +581,9 @@ class Player(Gtk.Box):
         self.adj_timeout = GLib.timeout_add(250, self.sync_adjustment)
         if load:
             self.playbin.set_volume(self.app.conf['volume'])
-            print('Player.start_player():')
-            print(self.playbin.get_volume(), '---', self.volume.get_value())
             self.init_meta()
             GLib.timeout_add(1500, self.init_adjustment)
-            self.notify.refresh()
+        self.notify.refresh()
 
     def start_player_cb(self, load=False):
         GLib.idle_add(self.start_player, load)
@@ -608,6 +598,7 @@ class Player(Gtk.Box):
         if self.adj_timeout > 0:
             GLib.source_remove(self.adj_timeout)
             self.adj_timeout = 0
+        self.notify.refresh()
 
     def pause_player_cb(self):
         GLib.idle_add(self.pause_player)
@@ -667,17 +658,14 @@ class Player(Gtk.Box):
                 self.load(self.curr_song)
             return
 
-        _repeat = self.repeat_btn.get_active()
-        _shuffle = self.shuffle_btn.get_active()
-        if self.next_song is None:
-            return
+        repeat = self.repeat_btn.get_active()
+        shuffle = self.shuffle_btn.get_active()
         if self.play_type == PlayType.RADIO:
-            #self.load_radio(self.next_song, self.curr_radio_item)
             self.curr_radio_item.play_next_song()
         elif self.play_type == PlayType.SONG:
-            self.app.playlist.play_next_song(repeat=_repeat, use_mv=False)
+            self.app.playlist.play_next_song(repeat, shuffle, use_mv=False)
         elif self.play_type == PlayType.MV:
-            self.app.playlist.play_next_song(repeat=_repeat, use_mv=True)
+            self.app.playlist.play_next_song(repeat, shuffle, use_mv=True)
 
     def load_next_cb(self):
         GLib.idle_add(self.load_next)
@@ -687,7 +675,6 @@ class Player(Gtk.Box):
 
     def set_volume(self, volume, refresh=True):
         mod_volume = volume ** 3
-        print('Player.set_volume()', volume, mod_volume)
         self.app.conf['volume'] = mod_volume
         self.playbin.set_volume(mod_volume)
         if refresh:
